<?php

namespace Drupal\imce_private\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\editor\Entity\Editor;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines the "imceprivate" plugin.
 *
 * @CKEditorPlugin(
 *   id = "imceprivate",
 *   label = @Translation("ImcePrivate"),
 * )
 */
class ImcePrivate extends CKEditorPluginBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return \Drupal::service('extension.list.module')->getPath('imce_private') . '/js/plugins/ckeditor/imce.ckeditor.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'ImceImagePrivate' => [
        'label' => $this->t('Insert private images using Imce File Manager'),
        'image' => $this->getIconPath('imceimage_private'),
      ],
      'ImceLinkPrivate' => [
        'label' => $this->t('Insert private file links using Imce File Manager'),
        'image' => $this->getIconPath('imcelink_private'),
      ],
      'ImceImagePublic' => [
        'label' => $this->t('Insert public images using Imce File Manager'),
        'image' => $this->getIconPath('imceimage_public'),
      ],
      'ImceLinkPublic' => [
        'label' => $this->t('Insert public file links using Imce File Manager'),
        'image' => $this->getIconPath('imcelink_public'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [
      'ImceImageIconPrivate' => \Drupal::service('file_url_generator')->generateAbsoluteString($this->getIconPath('imceimage_private')),
      'ImceLinkIconPrivate' => \Drupal::service('file_url_generator')->generateAbsoluteString($this->getIconPath('imcelink_private')),
      'ImceImageIconPublic' => \Drupal::service('file_url_generator')->generateAbsoluteString($this->getIconPath('imceimage_public')),
      'ImceLinkIconPublic' => \Drupal::service('file_url_generator')->generateAbsoluteString($this->getIconPath('imcelink_public')),
    ];
  }

  /**
   * Returns private image icon path.
   */
  private function getIconPath($icon) {
    return \Drupal::service('extension.list.module')->getPath('imce_private') . '/js/plugins/ckeditor/icons/' . $icon . '.png';
  }

}
